@@ -6,7 +6,6 @@ import io
 import aiohttp
 from typing import AsyncGenerator
 
-from rath.parsers.base import Parser
 
 FILE_CLASSES = (
     io.IOBase,
@@ -57,9 +56,8 @@ def parse_variables(
 
 
 class FileExtraction(ContinuationLink):
-    def __init__(self, file_path: str) -> None:
+    def __init__(self) -> None:
         super().__init__()
-        self.file_path = file_path
 
     async def aquery(self, operation: Operation) -> Operation:
         operation.variables, operation.context.files = parse_variables(
