@@ -3,10 +3,6 @@ from rath.operation import Operation
 
 
 class ParsingLink(ContinuationLink):
-    def __init__(self, file_path: str) -> None:
-        super().__init__()
-        self.file_path = file_path
-
     def parse(self, operation: Operation) -> Operation:
         raise NotImplementedError("Please implement this method")
 
